==> XS-Install-1.5.0.tar.gz: XS-Install-1.5.0/lib/XS/Install/FrozenShit/ParseXS/Eval.pm <==
package
  XS::Install::FrozenShit::ParseXS::Eval;
use strict;
use warnings;

our $VERSION = '3.57';

=head1 NAME

XS::Install::FrozenShit::ParseXS::Eval - Clean package to evaluate code in

=head1 SYNOPSIS

  use XS::Install::FrozenShit::ParseXS::Eval;
  my $rv = XS::Install::FrozenShit::ParseXS::Eval::eval_typemap_code(
    $parsexs_obj, "some Perl code"
  );

=head1 SUBROUTINES

=head2 $pxs->eval_output_typemap_code($typemapcode, $other_hashref)

Sets up various bits of previously global state
(formerly XS::Install::FrozenShit::ParseXS package variables)
for eval'ing output typemap code that may refer to these
variables.

Warns the contents of C<$@> if any.

Not all these variables are necessarily considered "public" wrt. use in
typemaps, so beware. Variables set up from the XS::Install::FrozenShit::ParseXS object:

  $Package $ALIAS $func_name $Full_func_name $pname

Variables set up from C<$other_hashref>:

  $var $type $ntype $subtype $arg

=cut

sub eval_output_typemap_code {
  my ($_pxs, $_code, $_other) = @_;

  my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
                  xsub_func_full_C_name xsub_func_full_perl_name)};

  my ($var, $type, $ntype, $subtype, $arg)
    = @{$_other}{qw(var type ntype subtype arg)};

  my $rv = eval $_code;
  warn $@ if $@;
  return $rv;
}

=head2 $pxs->eval_input_typemap_code($typemapcode, $other_hashref)

Sets up various bits of previously global state
(formerly XS::Install::FrozenShit::ParseXS package variables)
for eval'ing output typemap code that may refer to these
variables.

Warns the contents of C<$@> if any.

Not all these variables are necessarily considered "public" wrt. use in
typemaps, so beware. Variables set up from the XS::Install::FrozenShit::ParseXS object:

  $Package $ALIAS $func_name $Full_func_name $pname

Variables set up from C<$other_hashref>:

  $var $type $ntype $subtype $num $init $printed_name $arg $argoff

=cut

sub eval_input_typemap_code {
  my ($_pxs, $_code, $_other) = @_;

  my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
                  xsub_func_full_C_name xsub_func_full_perl_name)};

  my ($var, $type, $num, $init, $printed_name, $arg, $ntype, $argoff, $subtype)
    = @{$_other}{qw(var type num init printed_name arg ntype argoff subtype)};

  my $rv = eval $_code;
  warn $@ if $@;
  return $rv;
}

=head1 TODO

Eventually, with better documentation and possible some cleanup,
this could be part of C<ExtUtils::Typemaps>.

=cut

1;

# vim: ts=2 sw=2 et:

==> XS-Install-1.5.2.tar.gz: XS-Install-1.5.2/lib/XS/Install/FrozenShit/ParseXS/Eval.pm <==
package
  XS::Install::FrozenShit::ParseXS::Eval;
use strict;
use warnings;

our $VERSION = '3.57';

=head1 NAME

XS::Install::FrozenShit::ParseXS::Eval - Clean package to evaluate code in

=head1 SYNOPSIS

  use XS::Install::FrozenShit::ParseXS::Eval;
  my $rv = XS::Install::FrozenShit::ParseXS::Eval::eval_typemap_code(
    $parsexs_obj, "some Perl code"
  );

=head1 SUBROUTINES

=head2 $pxs->eval_output_typemap_code($typemapcode, $other_hashref)

Sets up various bits of previously global state
(formerly XS::Install::FrozenShit::ParseXS package variables)
for eval'ing output typemap code that may refer to these
variables.

Warns the contents of C<$@> if any.

Not all these variables are necessarily considered "public" wrt. use in
typemaps, so beware. Variables set up from the XS::Install::FrozenShit::ParseXS object:

  $Package $ALIAS $func_name $Full_func_name $pname

Variables set up from C<$other_hashref>:

  $var $type $ntype $subtype $arg

=cut

sub eval_output_typemap_code {
  my ($_pxs, $_code, $_other) = @_;

  my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
                  xsub_func_full_C_name xsub_func_full_perl_name)};

  my ($var, $type, $ntype, $subtype, $arg)
    = @{$_other}{qw(var type ntype subtype arg)};

  my $rv = eval $_code;
  warn $@ if $@;
  return $rv;
}

=head2 $pxs->eval_input_typemap_code($typemapcode, $other_hashref)

Sets up various bits of previously global state
(formerly XS::Install::FrozenShit::ParseXS package variables)
for eval'ing output typemap code that may refer to these
variables.

Warns the contents of C<$@> if any.

Not all these variables are necessarily considered "public" wrt. use in
typemaps, so beware. Variables set up from the XS::Install::FrozenShit::ParseXS object:

  $Package $ALIAS $func_name $Full_func_name $pname

Variables set up from C<$other_hashref>:

  $var $type $ntype $subtype $num $init $printed_name $arg $argoff

=cut

sub eval_input_typemap_code {
  my ($_pxs, $_code, $_other) = @_;

  my ($Package, $ALIAS, $func_name, $Full_func_name, $pname)
    = @{$_pxs}{qw(PACKAGE_name xsub_seen_ALIAS xsub_func_name
                  xsub_func_full_C_name xsub_func_full_perl_name)};

  my ($var, $type, $num, $init, $printed_name, $arg, $ntype, $argoff, $subtype)
    = @{$_other}{qw(var type num init printed_name arg ntype argoff subtype)};

  my $rv = eval $_code;
  warn $@ if $@;
  return $rv;
}

=head1 TODO

Eventually, with better documentation and possible some cleanup,
this could be part of C<XS::Install::FrozenShit::Typemaps>.

=cut

1;

# vim: ts=2 sw=2 et:
